[−][src]Enum unicode_types::mende_kikakui::MendeKikakui
An enum to represent all characters in the MendeKikakui block.
Variants
SyllableM001Ki\u{1e800}: '𞠀'
SyllableM002Ka\u{1e801}: '𞠁'
SyllableM003Ku\u{1e802}: '𞠂'
SyllableM065Kee\u{1e803}: '𞠃'
SyllableM095Ke\u{1e804}: '𞠄'
SyllableM076Koo\u{1e805}: '𞠅'
SyllableM048Ko\u{1e806}: '𞠆'
SyllableM179Kua\u{1e807}: '𞠇'
SyllableM004Wi\u{1e808}: '𞠈'
SyllableM005Wa\u{1e809}: '𞠉'
SyllableM006Wu\u{1e80a}: '𞠊'
SyllableM126Wee\u{1e80b}: '𞠋'
SyllableM118We\u{1e80c}: '𞠌'
SyllableM114Woo\u{1e80d}: '𞠍'
SyllableM045Wo\u{1e80e}: '𞠎'
SyllableM194Wui\u{1e80f}: '𞠏'
SyllableM143Wei\u{1e810}: '𞠐'
SyllableM061Wvi\u{1e811}: '𞠑'
SyllableM049Wva\u{1e812}: '𞠒'
SyllableM139Wve\u{1e813}: '𞠓'
SyllableM007Min\u{1e814}: '𞠔'
SyllableM008Man\u{1e815}: '𞠕'
SyllableM009Mun\u{1e816}: '𞠖'
SyllableM059Men\u{1e817}: '𞠗'
SyllableM094Mon\u{1e818}: '𞠘'
SyllableM154Muan\u{1e819}: '𞠙'
SyllableM189Muen\u{1e81a}: '𞠚'
SyllableM010Bi\u{1e81b}: '𞠛'
SyllableM011Ba\u{1e81c}: '𞠜'
SyllableM012Bu\u{1e81d}: '𞠝'
SyllableM150Bee\u{1e81e}: '𞠞'
SyllableM097Be\u{1e81f}: '𞠟'
SyllableM103Boo\u{1e820}: '𞠠'
SyllableM138Bo\u{1e821}: '𞠡'
SyllableM013I\u{1e822}: '𞠢'
SyllableM014A\u{1e823}: '𞠣'
SyllableM015U\u{1e824}: '𞠤'
SyllableM163Ee\u{1e825}: '𞠥'
SyllableM100E\u{1e826}: '𞠦'
SyllableM165Oo\u{1e827}: '𞠧'
SyllableM147O\u{1e828}: '𞠨'
SyllableM137Ei\u{1e829}: '𞠩'
SyllableM131In\u{1e82a}: '𞠪'
SyllableM135In\u{1e82b}: '𞠫'
SyllableM195An\u{1e82c}: '𞠬'
SyllableM178En\u{1e82d}: '𞠭'
SyllableM019Si\u{1e82e}: '𞠮'
SyllableM020Sa\u{1e82f}: '𞠯'
SyllableM021Su\u{1e830}: '𞠰'
SyllableM162See\u{1e831}: '𞠱'
SyllableM116Se\u{1e832}: '𞠲'
SyllableM136Soo\u{1e833}: '𞠳'
SyllableM079So\u{1e834}: '𞠴'
SyllableM196Sia\u{1e835}: '𞠵'
SyllableM025Li\u{1e836}: '𞠶'
SyllableM026La\u{1e837}: '𞠷'
SyllableM027Lu\u{1e838}: '𞠸'
SyllableM084Lee\u{1e839}: '𞠹'
SyllableM073Le\u{1e83a}: '𞠺'
SyllableM054Loo\u{1e83b}: '𞠻'
SyllableM153Lo\u{1e83c}: '𞠼'
SyllableM110LongLe\u{1e83d}: '𞠽'
SyllableM016Di\u{1e83e}: '𞠾'
SyllableM017Da\u{1e83f}: '𞠿'
SyllableM018Du\u{1e840}: '𞡀'
SyllableM089Dee\u{1e841}: '𞡁'
SyllableM180Doo\u{1e842}: '𞡂'
SyllableM181Do\u{1e843}: '𞡃'
SyllableM022Ti\u{1e844}: '𞡄'
SyllableM023Ta\u{1e845}: '𞡅'
SyllableM024Tu\u{1e846}: '𞡆'
SyllableM091Tee\u{1e847}: '𞡇'
SyllableM055Te\u{1e848}: '𞡈'
SyllableM104Too\u{1e849}: '𞡉'
SyllableM069To\u{1e84a}: '𞡊'
SyllableM028Ji\u{1e84b}: '𞡋'
SyllableM029Ja\u{1e84c}: '𞡌'
SyllableM030Ju\u{1e84d}: '𞡍'
SyllableM157Jee\u{1e84e}: '𞡎'
SyllableM113Je\u{1e84f}: '𞡏'
SyllableM160Joo\u{1e850}: '𞡐'
SyllableM063Jo\u{1e851}: '𞡑'
SyllableM175LongJo\u{1e852}: '𞡒'
SyllableM031Yi\u{1e853}: '𞡓'
SyllableM032Ya\u{1e854}: '𞡔'
SyllableM033Yu\u{1e855}: '𞡕'
SyllableM109Yee\u{1e856}: '𞡖'
SyllableM080Ye\u{1e857}: '𞡗'
SyllableM141Yoo\u{1e858}: '𞡘'
SyllableM121Yo\u{1e859}: '𞡙'
SyllableM034Fi\u{1e85a}: '𞡚'
SyllableM035Fa\u{1e85b}: '𞡛'
SyllableM036Fu\u{1e85c}: '𞡜'
SyllableM078Fee\u{1e85d}: '𞡝'
SyllableM075Fe\u{1e85e}: '𞡞'
SyllableM133Foo\u{1e85f}: '𞡟'
SyllableM088Fo\u{1e860}: '𞡠'
SyllableM197Fua\u{1e861}: '𞡡'
SyllableM101Fan\u{1e862}: '𞡢'
SyllableM037Nin\u{1e863}: '𞡣'
SyllableM038Nan\u{1e864}: '𞡤'
SyllableM039Nun\u{1e865}: '𞡥'
SyllableM117Nen\u{1e866}: '𞡦'
SyllableM169Non\u{1e867}: '𞡧'
SyllableM176Hi\u{1e868}: '𞡨'
SyllableM041Ha\u{1e869}: '𞡩'
SyllableM186Hu\u{1e86a}: '𞡪'
SyllableM040Hee\u{1e86b}: '𞡫'
SyllableM096He\u{1e86c}: '𞡬'
SyllableM042Hoo\u{1e86d}: '𞡭'
SyllableM140Ho\u{1e86e}: '𞡮'
SyllableM083Heei\u{1e86f}: '𞡯'
SyllableM128Hoou\u{1e870}: '𞡰'
SyllableM053Hin\u{1e871}: '𞡱'
SyllableM130Han\u{1e872}: '𞡲'
SyllableM087Hun\u{1e873}: '𞡳'
SyllableM052Hen\u{1e874}: '𞡴'
SyllableM193Hon\u{1e875}: '𞡵'
SyllableM046Huan\u{1e876}: '𞡶'
SyllableM090Nggi\u{1e877}: '𞡷'
SyllableM043Ngga\u{1e878}: '𞡸'
SyllableM082Nggu\u{1e879}: '𞡹'
SyllableM115Nggee\u{1e87a}: '𞡺'
SyllableM146Ngge\u{1e87b}: '𞡻'
SyllableM156Nggoo\u{1e87c}: '𞡼'
SyllableM120Nggo\u{1e87d}: '𞡽'
SyllableM159Nggaa\u{1e87e}: '𞡾'
SyllableM127Nggua\u{1e87f}: '𞡿'
SyllableM086LongNgge\u{1e880}: '𞢀'
SyllableM106LongNggoo\u{1e881}: '𞢁'
SyllableM183LongNggo\u{1e882}: '𞢂'
SyllableM155Gi\u{1e883}: '𞢃'
SyllableM111Ga\u{1e884}: '𞢄'
SyllableM168Gu\u{1e885}: '𞢅'
SyllableM190Gee\u{1e886}: '𞢆'
SyllableM166Guei\u{1e887}: '𞢇'
SyllableM167Guan\u{1e888}: '𞢈'
SyllableM184Ngen\u{1e889}: '𞢉'
SyllableM057Ngon\u{1e88a}: '𞢊'
SyllableM177Nguan\u{1e88b}: '𞢋'
SyllableM068Pi\u{1e88c}: '𞢌'
SyllableM099Pa\u{1e88d}: '𞢍'
SyllableM050Pu\u{1e88e}: '𞢎'
SyllableM081Pee\u{1e88f}: '𞢏'
SyllableM051Pe\u{1e890}: '𞢐'
SyllableM102Poo\u{1e891}: '𞢑'
SyllableM066Po\u{1e892}: '𞢒'
SyllableM145Mbi\u{1e893}: '𞢓'
SyllableM062Mba\u{1e894}: '𞢔'
SyllableM122Mbu\u{1e895}: '𞢕'
SyllableM047Mbee\u{1e896}: '𞢖'
SyllableM188Mbee\u{1e897}: '𞢗'
SyllableM072Mbe\u{1e898}: '𞢘'
SyllableM172Mboo\u{1e899}: '𞢙'
SyllableM174Mbo\u{1e89a}: '𞢚'
SyllableM187Mbuu\u{1e89b}: '𞢛'
SyllableM161LongMbe\u{1e89c}: '𞢜'
SyllableM105LongMboo\u{1e89d}: '𞢝'
SyllableM142LongMbo\u{1e89e}: '𞢞'
SyllableM132Kpi\u{1e89f}: '𞢟'
SyllableM092Kpa\u{1e8a0}: '𞢠'
SyllableM074Kpu\u{1e8a1}: '𞢡'
SyllableM044Kpee\u{1e8a2}: '𞢢'
SyllableM108Kpe\u{1e8a3}: '𞢣'
SyllableM112Kpoo\u{1e8a4}: '𞢤'
SyllableM158Kpo\u{1e8a5}: '𞢥'
SyllableM124Gbi\u{1e8a6}: '𞢦'
SyllableM056Gba\u{1e8a7}: '𞢧'
SyllableM148Gbu\u{1e8a8}: '𞢨'
SyllableM093Gbee\u{1e8a9}: '𞢩'
SyllableM107Gbe\u{1e8aa}: '𞢪'
SyllableM071Gboo\u{1e8ab}: '𞢫'
SyllableM070Gbo\u{1e8ac}: '𞢬'
SyllableM171Ra\u{1e8ad}: '𞢭'
SyllableM123Ndi\u{1e8ae}: '𞢮'
SyllableM129Nda\u{1e8af}: '𞢯'
SyllableM125Ndu\u{1e8b0}: '𞢰'
SyllableM191Ndee\u{1e8b1}: '𞢱'
SyllableM119Nde\u{1e8b2}: '𞢲'
SyllableM067Ndoo\u{1e8b3}: '𞢳'
SyllableM064Ndo\u{1e8b4}: '𞢴'
SyllableM152Nja\u{1e8b5}: '𞢵'
SyllableM192Nju\u{1e8b6}: '𞢶'
SyllableM149Njee\u{1e8b7}: '𞢷'
SyllableM134Njoo\u{1e8b8}: '𞢸'
SyllableM182Vi\u{1e8b9}: '𞢹'
SyllableM185Va\u{1e8ba}: '𞢺'
SyllableM151Vu\u{1e8bb}: '𞢻'
SyllableM173Vee\u{1e8bc}: '𞢼'
SyllableM085Ve\u{1e8bd}: '𞢽'
SyllableM144Voo\u{1e8be}: '𞢾'
SyllableM077Vo\u{1e8bf}: '𞢿'
SyllableM164Nyin\u{1e8c0}: '𞣀'
SyllableM058Nyan\u{1e8c1}: '𞣁'
SyllableM170Nyun\u{1e8c2}: '𞣂'
SyllableM098Nyen\u{1e8c3}: '𞣃'
SyllableM060Nyon\u{1e8c4}: '𞣄'
DigitOne\u{1e8c7}: '𞣇'
DigitTwo\u{1e8c8}: '𞣈'
DigitThree\u{1e8c9}: '𞣉'
DigitFour\u{1e8ca}: '𞣊'
DigitFive\u{1e8cb}: '𞣋'
DigitSix\u{1e8cc}: '𞣌'
DigitSeven\u{1e8cd}: '𞣍'
DigitEight\u{1e8ce}: '𞣎'
DigitNine\u{1e8cf}: '𞣏'
CombiningNumberTeens\u{1e8d0}: '𞣐'
CombiningNumberTens\u{1e8d1}: '𞣑'
CombiningNumberHundreds\u{1e8d2}: '𞣒'
CombiningNumberThousands\u{1e8d3}: '𞣓'
CombiningNumberTenThousands\u{1e8d4}: '𞣔'
CombiningNumberHundredThousands\u{1e8d5}: '𞣕'
CombiningNumberMillions\u{1e8d6}: '𞣖'
Methods
impl MendeKikakui[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case